/**
 * Copyright 2012 Miroslav Šulc
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.fordfrog.ruian2pgsql.utils;

import java.io.IOException;
import java.io.Writer;

/**
 * Logging utility class.
 *
 * @author fordfrog
 */
public class Log {

    /**
     * Log writer.
     */
    private static Writer writer;

    /**
     * Sets log output stream.
     *
     * @param writer {@link #writer}
     */
    public static void setLogWriter(final Writer writer) {
        Log.writer = writer;
    }

    /**
     * Prints text to log writer.
     *
     * @param text text
     */
    public static void write(final String text) {
        try {
            writer.write(text);
            writer.write('\n');
        } catch (final IOException ex) {
            throw new RuntimeException("Failed to write to log file", ex);
        }
    }

    /**
     * Flushes log buffer.
     */
    public static void flush() {
        try {
            writer.flush();
        } catch (final IOException ex) {
            throw new RuntimeException("Failed to flush log", ex);
        }
    }

    /**
     * Creates new instance of Log.
     */
    private Log() {
    }
}
